@@ -92,6 +92,8 @@ import jsii
 import publication
 import typing_extensions
 
+from typeguard import check_type
+
 from ._jsii import *
 
 import constructs
@@ -120,6 +122,10 @@ class EcrImageScanNotify(
 
         :stability: experimental
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(EcrImageScanNotify.__init__)
+            check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
+            check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         props = EcrImageScanNotifyProps(webhook_url=webhook_url)
 
         jsii.create(self.__class__, self, [scope, id, props])
@@ -137,6 +143,9 @@ class EcrImageScanNotifyProps:
 
         :stability: experimental
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(EcrImageScanNotifyProps.__init__)
+            check_type(argname="argument webhook_url", value=webhook_url, expected_type=type_hints["webhook_url"])
         self._values: typing.Dict[str, typing.Any] = {
             "webhook_url": webhook_url,
         }
